<?php
$explan = 'ファイルが更新されたら<span style="color:crimson;font-weight:bold;">new!</span>表示する。
<pre>[[show_new(\'path=./test.txt|days=10\')]]</pre>のように記述する。引数はチェックするファイルのパスとnew表示する日数。
日数を省略するとデフォルトの7日になる。term.php関連以外のファイルを指定することもできる。
更新日時をチェックするファイル名が特定できない場合、正規表現によるファイルパスの指定も可能だが、制限がある。
<pre>[[show_new(\'path=/\.\/data\/^\w+\.cgi$/\')]]</pre>のように、チェックするファイルパスの先頭と末尾を\'/\'にすると、正規表現パターンと判断する。
その際ディレクトリの記述に「.」や「/」を使用するので、「\.」や「\/」とエスケープして記述する必要があるが、ディレクトリ部分は正規表現を使った検索は行わない。
記述したパターンの最後の「\/」までを検索対象ディレクトリとしてアンエススケープし、それ以降がそのディレクトリ内でのファイルの検索に使用する正規表現パターンとなる。
上記の例では<b>./data</b>ディレクトリ内で<b>\'/^\w+\.cgi$/\'</b>という正規表現パターンにマッチするファイルを検索することになる。
パターンにマッチする最新のファイルの更新時間に基づいて<span style="color:crimson;font-weight:bold;">new!</span>表示する。
<h3>指定できるオプション</h3>
<dl><dt>path</dt><dd>更新をチェックするファイルのパス　必須</dd></dl>
<dl><dt>days</dt><dd>new!表示する日数　省略すると7日間になる</dd></dl>
<dl><dt>str</dt><dd>new!の代わりに表示する文字列　省略するとnew!になる　timeを指定すると更新日時が表示される
</dd></dl>
<dl><dt>style</dt><dd>new!表示文字列のスタイルを指定する</dd></dl>
';
$format = "[[show_new('path=./term.php|days=7')]]
[[show_new('path=/\w\.php/')]]	// 正規表現も使用可
[[show_new('path=/\.\/data\/\w{10}\.cgi$/|str=time|style=color:red;font-weight:bold;')]]
";

////////////////////////////////////////////////////////
// article_id()			記事のIDを取得
// article_dir($id)		記事用ディレクトリ
// tag_convert($html)	指定タグ以外を無効化
// week_name($year,$month,$day)	年月日から曜日を取得
// get_holiday($year,$month,$day)	祝日を取得
////////////////////////////////////////////////////////

function show_new( $option = '' ) {
	global $datadir;
	if ($option) {
		$tmp = explode('|',$option);
		$option = array();
		foreach ($tmp as $_) {
			$tmp2 = explode('=',$_);
			if (isset($tmp2[0]) && isset($tmp2[1])) { $option[$tmp2[0]] = $tmp2[1]; }
		}
	}
	if (! isset($option['path']) || ! $option['path']) {
		return 'pathの指定は必須です';
	}
	if (! isset($option['days'])) { $option['days'] = 7; }
	if (! isset($option['str'])) { $option['str'] = 'new!'; }
	if (! isset($option['style'])) { $option['style'] = ''; }
	if (! isset($option['show_file_name'])) { $option['show_file_name'] = ''; }
	$str = '';
	if (preg_match('/^\/(.+)\/$/',$option['path'],$matched)) {
		// 正規表現と判断
		$tmp = explode('\/',$matched[1]);
		$file = end($tmp);
		$ptn = '/' . $file . '/';
		array_pop($tmp);
		$tmp = join('\/',$tmp);
		$dir = stripslashes($tmp);
		if (!$dir) {
			$dir = '.';
		}
		$newest_mtime = 0;
		if (is_dir($dir)) {
			$tmpdir = opendir($dir);
			
			while ($file = readdir($tmpdir)) {
				if (preg_match($ptn,$file)) {
					$mtime = filemtime(join('/',array($dir,$file)));
					if ($newest_mtime < $mtime) {
						$newest_mtime = $mtime;
						$newest_path = join('/',array($dir,$file));
					}
				}
			}
		}
		if ($newest_mtime > time() - $option['days']*3600*24) {
			if ($option['style']) {
				if ($option['str'] == 'time') {
					$str .= "<span style=\"" . $option['style'] . "\">" . date('Y-m-d H:i:s',$newest_mtime) . '更新' . "</span>";
				} else {
					$str .= "<span style=\"" . $option['style'] . "\">" . $option['str'] . "</span>";
				}
			} else {
				if ($option['str'] == 'time') {
					$str .= date('Y-m-d H:i:s',$newest_mtime) . '更新';
				} else {
					$str .= $option['str'];
				}
			}
		}
	} elseif ($option['path'] && file_exists($option['path'])) {
		$tm = filemtime($option['path']);
		if ($tm + $option['days']*3600*24 > time()) {
			if ($option['style']) {
				if ($option['str'] == 'time') {
					$str .= "<span style=\"" . $option['style'] . "\">" . date('Y-m-d H:i:s',$tm) . '更新' . "</span>";
				} else {
					$str .= "<span style=\"" . $option['style'] . "\">" . $option['str'] . "</span>";
				}
			} else {
				if ($option['str'] == 'time') {
					$str .= date('Y-m-d H:i:s',$tm) . '更新';
				} else {
					$str .= $option['str'];
				}
			}
		}
	}
	if ($option['show_file_name']) {
		if (preg_match('|' . $datadir . '/.+\.cgi$|', $newest_path)) {
			$log = file($newest_path);
			$tmp = explode('<>',$log[array_key_last($log)]);
			$str .= ' ' . $tmp[2];
		} else {
			$str .= $newest_path;
		}
	}
	return $str;
}
?>